import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:npay_component/components/tab_bar_widget/tab_button.dart';

class NPTabBarController extends ValueNotifier<int> {
  /// Creates a controller for an control tab bar index.
  NPTabBarController({int index}) : super(index ?? 0);
}

class NPTabBar extends StatefulWidget {
  ///
  final List<String> titles;

  final List<Widget> tabView;

  final Function(int tabIndex) onPressed;

  final NPTabBarController tabController;

  final EdgeInsetsGeometry padding;

  final Color color;
  const NPTabBar(
      {Key key,
      @required this.titles,
      this.onPressed,
      this.padding = EdgeInsets.zero,
      this.color = Colors.white,
      @required this.tabController,
      @required this.tabView})
      : super(key: key);

  @override
  _NPTabBarState createState() => _NPTabBarState();
}

class _NPTabBarState extends State<NPTabBar> with TickerProviderStateMixin{
  TabController _tabController;

  @override
  void initState() {
    _tabController = new TabController(
        length: widget.titles.length, vsync: this, initialIndex: widget.tabController.value);
    _tabController.addListener(() {
      widget.tabController.value = _tabController.index;
      if (widget.onPressed != null) widget.onPressed(_tabController.index);
    });
    widget.tabController.addListener(() {
      _tabController.animateTo(widget.tabController.value);
    });
    super.initState();
  }
  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder(
      builder: (BuildContext context, value, Widget child) {
        return Container(
          color: widget.color,
          child: Stack(
            alignment: Alignment.topCenter,
            children: [
              Padding(
                padding: widget.padding,
                child: Container(
                  height: 32,
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.all(Radius.circular(8.0)),
                    color: Color(0xFFF4F6FA),
                  ),
                  child: Row(
                    children: List.generate(widget.titles.length, (index) {
                      return Expanded(
                        child: TabButton(
                          selectedPage: _tabController.index,
                          pageNumber: index,
                          title: widget.titles[index],
                          onPressed: () {},
                        ),
                      );
                    }).toList(),
                  ),
                ),
              ),
              Column(
                children: [
                  TabBar(
                  tabs: _listTabBar(widget.titles.length, widget.titles),
                    controller: _tabController,
                    labelColor: Colors.transparent,
                    indicatorWeight: 1,
                    indicatorColor: Colors.transparent,
                  ),
                  Divider(
                    height: 0.5,
                    color: Color(0xffCFD2D8),
                  ),
                  Expanded(
                    child: TabBarView(
                      children: widget.tabView,
                      controller: _tabController,
                    ),
                  )
                ],
              ),
              // Expanded(
              //     child: IndexedStack(
              //   children: widget.tabView,
              //   index: widget.tabController.value,
              // ))
            ],
          ),
        );
      },
      valueListenable: widget.tabController,
    );
  }

  _listTabBar(int length,List<String> titles){
    return List.generate(length,
            (index) => Tab(
              text: '',
            ),
    );
  }
}
